@@ -271,7 +271,7 @@ int open_game( Pairs *pairs, int width, int height )
 void close_game( Pairs *pairs )
 {
     if ( cfg.fullscreen )
-        set_video_mode( 640, 480, 16, SDL_SWSURFACE );
+        set_video_mode( 800, 480, 16, SDL_FULLSCREEN );
 }
 
 /* run game */
@@ -294,7 +294,7 @@ void run_game( Pairs *pairs )
             switch ( event.type ) {
 
                 case SDL_KEYUP:
-                    if ( event.key.keysym.sym == SDLK_ESCAPE ) leave = 1;
+                    if ( event.key.keysym.sym == SDLK_BACKSPACE ) leave = 1;
                     if ( event.key.keysym.sym == SDLK_r ) restart = 1;
                     break;
 
